@@ -73,6 +73,11 @@ DeviceDetails::DeviceDetails(QObject *parent) :
 	modWarning(false),
 	dynamicAscendRate(false),
 	graphicalSpeedIndicator(false),
-	alwaysShowppO2(false)
+	alwaysShowppO2(false),
+	tempSensorOffset(0),
+	safetyStopLength(0),
+	safetyStopStartDepth(0),
+	safetyStopEndDepth(0),
+	safetyStopResetDepth(0)
 {
 }
