@@ -91,6 +91,11 @@ public:
 	bool dynamicAscendRate;
 	bool graphicalSpeedIndicator;
 	bool alwaysShowppO2;
+	int tempSensorOffset;
+	unsigned safetyStopLength;
+	unsigned safetyStopStartDepth;
+	unsigned safetyStopEndDepth;
+	unsigned safetyStopResetDepth;
 };
 
 
