@@ -1116,6 +1116,8 @@ static void fixup_water_salinity(struct dive *dive)
 
 	for_each_dc (dive, dc) {
 		if (dc->salinity) {
+			if (dc->salinity < 500)
+				dc->salinity += FRESHWATER_SALINITY;
 			sum += dc->salinity;
 			nr++;
 		}
@@ -2162,6 +2164,9 @@ static int find_sample_offset(struct divecomputer *a, struct divecomputer *b)
  */
 static int similar(unsigned long a, unsigned long b, unsigned long expected)
 {
+	if (!a && !b)
+		return 1;
+
 	if (a && b) {
 		unsigned long min, max, diff;
 
@@ -2352,6 +2357,20 @@ static void free_pic(struct picture *picture)
 	}
 }
 
+// When handling pictures in different threads, we need to copy them so we don't
+// run into problems when the main thread frees the picture.
+
+struct picture *clone_picture(struct picture *src)
+{
+	struct picture *dst;
+
+	dst = alloc_picture();
+	copy_pl(src, dst);
+	return dst;
+}
+
+
+
 static int same_sample(struct sample *a, struct sample *b)
 {
 	if (a->time.seconds != b->time.seconds)
@@ -3382,7 +3401,7 @@ void dive_set_geodata_from_picture(struct dive *dive, struct picture *picture)
 	}
 }
 
-static void picture_free(struct picture *picture)
+void picture_free(struct picture *picture)
 {
 	if (!picture)
 		return;
