@@ -376,6 +376,7 @@ struct picture {
 	for (struct picture *picture = (_divestruct).picture_list; picture; picture = picture->next)
 
 extern struct picture *alloc_picture();
+extern struct picture *clone_picture(struct picture *src);
 extern bool dive_check_picture_time(struct dive *d, int shift_time, timestamp_t timestamp);
 extern void dive_create_picture(struct dive *d, char *filename, int shift_time, bool match_all);
 extern void dive_add_picture(struct dive *d, struct picture *newpic);
@@ -385,6 +386,7 @@ extern bool picture_check_valid(char *filename, int shift_time);
 extern void picture_load_exif_data(struct picture *p);
 extern timestamp_t picture_get_timestamp(char *filename);
 extern void dive_set_geodata_from_picture(struct dive *d, struct picture *pic);
+extern void picture_free(struct picture *picture);
 
 extern int explicit_first_cylinder(struct dive *dive, struct divecomputer *dc);
 extern int get_depth_at_time(struct divecomputer *dc, int time);
@@ -409,6 +411,8 @@ static inline int calculate_depth_to_mbar(int depth, pressure_t surface_pressure
 		mbar = SURFACE_PRESSURE;
 	if (!salinity)
 		salinity = SEAWATER_SALINITY;
+	if (salinity < 500)
+		salinity += FRESHWATER_SALINITY;
 	specific_weight = salinity / 10000.0 * 0.981;
 	mbar += rint(depth / 10.0 * specific_weight);
 	return mbar;
