@@ -1,9 +1,12 @@
 #ifndef PRINTDIALOG_H
 #define PRINTDIALOG_H
 
+#ifndef NO_PRINTING
 #include <QDialog>
 #include <QPrinter>
-#include "../display.h"
+#include "printoptions.h"
+#include "printer.h"
+#include "templateedit.h"
 
 class QProgressBar;
 class PrintOptions;
@@ -18,10 +21,11 @@ public:
 
 private:
 	PrintOptions *optionsWidget;
-	PrintLayout *printLayout;
 	QProgressBar *progressBar;
-	QPrinter printer;
+	Printer *printer;
+	QPrinter qprinter;
 	struct print_options printOptions;
+	struct template_options templateOptions;
 
 private
 slots:
@@ -30,4 +34,5 @@ slots:
 	void printClicked();
 	void onPaintRequested(QPrinter *);
 };
+#endif
 #endif // PRINTDIALOG_H
